@@ -1,5 +1,4 @@
 import json
-import tablib
 from collections import OrderedDict
 from copy import deepcopy
 from datetime import date
@@ -7,6 +6,7 @@ from decimal import Decimal
 from unittest import mock, skip, skipIf, skipUnless
 
 import django
+import tablib
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.exceptions import ValidationError
@@ -31,7 +31,7 @@ from ..models import (
     Role,
     WithDefault,
     WithDynamicDefault,
-    WithFloatField
+    WithFloatField,
 )
 
 if django.VERSION[0] >= 3:
@@ -344,7 +344,7 @@ class ModelResourceTest(TestCase):
         qs = Book.objects.all()
         with mock.patch.object(qs, "iterator") as mocked_method:
             list(self.resource.iter_queryset(qs))
-            mocked_method.assert_called_once_with(chunk_size=1)
+            mocked_method.assert_called_once_with(chunk_size=100)
 
     def test_iter_queryset_prefetch_unordered(self):
         qsu = Book.objects.prefetch_related("categories").all()
@@ -357,9 +357,9 @@ class ModelResourceTest(TestCase):
     def test_iter_queryset_prefetch_ordered(self):
         qs = Book.objects.prefetch_related("categories").order_by('pk').all()
         with mock.patch("import_export.resources.Paginator", autospec=True) as p:
-            p.return_value = Paginator(qs, 1)
+            p.return_value = Paginator(qs, 100)
             list(self.resource.iter_queryset(qs))
-            p.assert_called_once_with(qs, 1)
+            p.assert_called_once_with(qs, 100)
 
     def test_iter_queryset_prefetch_chunk_size(self):
         class B(BookResource):
